@@ -22,8 +22,8 @@ along with this program.  If not, see
 <http://www.gnu.org/licenses/>.
 """
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt5.QtCore import *
+from PyQt5.QtWidgets import *
 import re, collections
 
 class bashProcess(QProcess):
